@@ -131,13 +131,29 @@ battfink_battery_icon_changed_callback (GConfClient *client, guint id, GConfEntr
     BATTFINK_APM_GET_CLASS (fink->priv->fink_apm)->disable (fink->priv->fink_apm, fink->priv->tray_icon);
 }
 
+static void battfink_client_init_dialog (GladeXML *glade_xml, BattfinkClient *fink_client);
+static GladeXML * battfink_client_load_xml (void);
+
 static void
-battfink_client_invoke_preferences (BattfinkApm *fink_apm)
+battfink_client_invoke_preferences (BattfinkApm *fink_apm, gpointer user_data)
 {
   GtkWindow *window;
+  BattfinkClient *fink_client;
+  GladeXML *glade_xml;
+  GtkWidget *dialog;
 
   window = battfink_client_get_active_window (BATTFINK_CLIENT (fink_apm->parent));
-  gtk_window_present (window);
+  if (window) {
+    gtk_window_present (window);
+    return;
+  }
+
+  fink_client = BATTFINK_CLIENT (fink_client);
+  glade_xml = battfink_client_load_xml ();
+  dialog = glade_xml_get_widget (glade_xml, "battfink_dialog");
+  battfink_client_init_dialog (glade_xml, fink_client);
+
+  fink_client->priv->windows = g_slist_append (fink_client->priv->windows, GTK_WINDOW (dialog));
 }
 
 static void
@@ -168,7 +184,7 @@ battfink_client_init (BattfinkClient *fink)
 
   fink->priv->tray_icon = egg_tray_icon_new ("Battfink");
   g_signal_connect (G_OBJECT (fink->priv->fink_apm), "preferences",
-                    G_CALLBACK (battfink_client_invoke_preferences), NULL);
+                    G_CALLBACK (battfink_client_invoke_preferences), fink);
   g_signal_connect (G_OBJECT (fink->priv->fink_apm), "disable",
                     G_CALLBACK (battfink_client_disable_icon), NULL);
 
@@ -215,7 +231,7 @@ battfink_client_new (void)
   return fink;
 }
 
-GladeXML *
+static GladeXML *
 battfink_client_load_xml (void)
 {
   GladeXML *xml = NULL;
